# 💫 Get Started

Welcome to the world of Retriever Augmented Generation (RAG) models and evaluations.

```{note}
All of this tutorials give a quick look at what you can do with ragrank. You can customize most of the things in here. But at first don't worry about it. Just get things done. After a bit exploration checkout [core-concepts](../core_concepts/index.md) to learn more about each evaluations. Don't forget to checkout the [evaluations](../evaluation/index.md) as well.
```

----

````{grid}
:gutter: 2

```{grid-item-card} 🚀 Quick Start
:link: quick-start
:link-type: ref

Master the basics of `ragrank` with a strong step. Evaluate RAG pipelines, generate test sets, and set up online monitoring for RAG apps — all with a few lines of code.
```

```{grid-item-card} 🍭 Basic Evaluation
:link: basic-evaluation
:link-type: ref

Every expert was once a beginner. Start your `ragrank` journey with a basic evaluation that everybody can understand. Have the courage to learn about investigating your LLM and RAG models.
```
````

```{toctree}
:hidden:

quick_start
basic_evaluation
```
